@@ -4,7 +4,7 @@
 ## Copyright (C) 2005-2006 Andrew Sayman <lorien420 AT myrealbox.com>
 ##                         Dimitur Kirov <dkirov AT gmail.com>
 ##                         Nikos Kouremenos <kourem AT gmail.com>
-## Copyright (C) 2005-2010 Yann Leboulanger <asterix AT lagaule.org>
+## Copyright (C) 2005-2012 Yann Leboulanger <asterix AT lagaule.org>
 ## Copyright (C) 2006-2007 Travis Shirk <travis AT pobox.com>
 ## Copyright (C) 2006-2008 Jean-Marie Traissard <jim AT lapin.org>
 ## Copyright (C) 2007 Lukas Petrovicky <lukas AT petrovicky.net>
@@ -36,13 +36,13 @@ from common import gajim
 from common import helpers
 from time import time
 from dialogs import AddNewContactWindow, NewChatDialog, JoinGroupchatWindow
+from common import ged
 
 from common import dbus_support
 if dbus_support.supported:
     import dbus
     if dbus_support:
         import dbus.service
-        import dbus.glib
 
 INTERFACE = 'org.gajim.dbus.RemoteInterface'
 OBJ_PATH = '/org/gajim/dbus/RemoteObject'
@@ -104,6 +104,111 @@ class Remote:
         bus_name = dbus.service.BusName(SERVICE, bus=session_bus)
         self.signal_object = SignalObject(bus_name)
 
+        gajim.ged.register_event_handler('last-result-received', ged.POSTGUI,
+            self.on_last_status_time)
+        gajim.ged.register_event_handler('version-result-received', ged.POSTGUI,
+            self.on_os_info)
+        gajim.ged.register_event_handler('time-result-received', ged.POSTGUI,
+            self.on_time)
+        gajim.ged.register_event_handler('gmail-nofify', ged.POSTGUI,
+            self.on_gmail_notify)
+        gajim.ged.register_event_handler('roster-info', ged.POSTGUI,
+            self.on_roster_info)
+        gajim.ged.register_event_handler('presence-received', ged.POSTGUI,
+            self.on_presence_received)
+        gajim.ged.register_event_handler('subscribe-presence-received',
+            ged.POSTGUI, self.on_subscribe_presence_received)
+        gajim.ged.register_event_handler('subscribed-presence-received',
+            ged.POSTGUI, self.on_subscribed_presence_received)
+        gajim.ged.register_event_handler('unsubscribed-presence-received',
+            ged.POSTGUI, self.on_unsubscribed_presence_received)
+        gajim.ged.register_event_handler('gc-message-received',
+            ged.POSTGUI, self.on_gc_message_received)
+        gajim.ged.register_event_handler('our-show', ged.POSTGUI,
+            self.on_our_status)
+        gajim.ged.register_event_handler('account-created', ged.POSTGUI,
+            self.on_account_created)
+        gajim.ged.register_event_handler('vcard-received', ged.POSTGUI,
+            self.on_vcard_received)
+        gajim.ged.register_event_handler('chatstate-received', ged.POSTGUI,
+            self.on_chatstate_received)
+        gajim.ged.register_event_handler('message-sent', ged.POSTGUI,
+            self.on_message_sent)
+
+    def on_chatstate_received(self, obj):
+        self.raise_signal('ChatState', (obj.conn.name, [
+            obj.jid, obj.fjid, obj.stanza, obj.resource, obj.composing_xep,
+            obj.chatstate]))
+
+    def on_message_sent(self, obj):
+        try:
+            chatstate = obj.chatstate
+        except AttributeError:
+            chatstate = ""
+        self.raise_signal('MessageSent', (obj.conn.name, [
+            obj.jid, obj.message, obj.keyID, chatstate]))
+
+    def on_last_status_time(self, obj):
+        self.raise_signal('LastStatusTime', (obj.conn.name, [
+            obj.jid, obj.resource, obj.seconds, obj.status]))
+
+    def on_os_info(self, obj):
+        self.raise_signal('OsInfo', (obj.conn.name, [obj.jid, obj.resource,
+            obj.client_info, obj.os_info]))
+
+    def on_time(self, obj):
+        self.raise_signal('EntityTime', (obj.conn.name, [obj.jid, obj.resource,
+            obj.time_info]))
+
+    def on_gmail_notify(self, obj):
+        self.raise_signal('NewGmail', (obj.conn.name, [obj.jid, obj.newmsgs,
+            obj.gmail_messages_list]))
+
+    def on_roster_info(self, obj):
+        self.raise_signal('RosterInfo', (obj.conn.name, [obj.jid, obj.nickname,
+            obj.sub, obj.ask, obj.groups]))
+
+    def on_presence_received(self, obj):
+        event = None
+        if obj.old_show < 2 and obj.new_show > 1:
+            event = 'ContactPresence'
+        elif obj.old_show > 1 and obj.new_show < 2:
+            event = 'ContactAbsence'
+        elif obj.new_show > 1:
+            event = 'ContactStatus'
+        if event:
+            self.raise_signal(event, (obj.conn.name, [obj.jid, obj.show,
+                obj.status, obj.resource, obj.prio, obj.keyID, obj.timestamp,
+                obj.contact_nickname]))
+
+    def on_subscribe_presence_received(self, obj):
+        self.raise_signal('Subscribe', (obj.conn.name, [obj.jid, obj.status,
+            obj.user_nick]))
+
+    def on_subscribed_presence_received(self, obj):
+        self.raise_signal('Subscribed', (obj.conn.name, [obj.jid,
+            obj.resource]))
+
+    def on_unsubscribed_presence_received(self, obj):
+        self.raise_signal('Unsubscribed', (obj.conn.name, obj.jid))
+
+    def on_gc_message_received(self, obj):
+        if not hasattr(obj, 'needs_highlight'):
+            # event has not been handled at GUI level
+            return
+        self.raise_signal('GCMessage', (obj.conn.name, [obj.fjid, obj.msgtxt,
+            obj.timestamp, obj.has_timestamp, obj.xhtml_msgtxt, obj.status_code,
+            obj.displaymarking, obj.captcha_form, obj.needs_highlight]))
+
+    def on_our_status(self, obj):
+        self.raise_signal('AccountPresence', (obj.show, obj.conn.name))
+
+    def on_account_created(self, obj):
+        self.raise_signal('NewAccount', (obj.conn.name, obj.account_info))
+
+    def on_vcard_received(self, obj):
+        self.raise_signal('VcardInfo', (obj.conn.name, obj.vcard_dict))
+
     def raise_signal(self, signal, arg):
         if self.signal_object:
             try:
@@ -199,6 +304,14 @@ class SignalObject(dbus.service.Object):
     def NewGmail(self, account_and_array):
         pass
 
+    @dbus.service.signal(INTERFACE, signature='av')
+    def ChatState(self, account_and_array):
+        pass
+
+    @dbus.service.signal(INTERFACE, signature='av')
+    def MessageSent(self, account_and_array):
+        pass
+
     def raise_signal(self, signal, arg):
         """
         Raise a signal, with a single argument of unspecified type Instead of
@@ -319,7 +432,18 @@ class SignalObject(dbus.service.Object):
         connected_account, contact = self._get_account_and_contact(account, jid)
         if connected_account:
             connection = gajim.connections[connected_account]
-            connection.send_message(jid, message, keyID, type_, subject)
+            sessions = connection.get_sessions(jid)
+            if sessions:
+                session = sessions[0]
+            else:
+                session = connection.make_new_session(jid)
+            ctrl = gajim.interface.msg_win_mgr.search_control(jid,
+                connected_account)
+            if ctrl:
+                ctrl.print_conversation(message, frm='outgoing')
+
+            connection.send_message(jid, message, keyID, type_, subject,
+                session=session)
             return DBUS_BOOLEAN(True)
         return DBUS_BOOLEAN(False)
 
@@ -370,6 +494,7 @@ class SignalObject(dbus.service.Object):
             # Jid is not conform, ignore it
             return DBUS_BOOLEAN(False)
 
+        minimized_control = None
         if account:
             accounts = [account]
         else:
@@ -386,6 +511,8 @@ class SignalObject(dbus.service.Object):
                     break
                 # jid is in roster
                 elif contact:
+                    minimized_control = \
+                        jid in gajim.interface.minimized_controls[acct]
                     connected_account = acct
                     break
                 # we send the message to jid not in roster, because account is
@@ -399,6 +526,10 @@ class SignalObject(dbus.service.Object):
         if connected_account is None and first_connected_acct:
             connected_account = first_connected_acct
 
+        if minimized_control:
+            gajim.interface.roster.on_groupchat_maximized(None, jid,
+                connected_account)
+
         if connected_account:
             gajim.interface.new_chat_from_jid(connected_account, jid, message)
             # preserve the 'steal focus preservation'
@@ -473,7 +604,10 @@ class SignalObject(dbus.service.Object):
         Show the window(s) with next pending event in tabbed/group chats
         """
         if gajim.events.get_nb_events():
-            gajim.interface.systray.handle_first_event()
+            account, jid, event = gajim.events.get_first_systray_event()
+            if not event:
+                return
+            gajim.interface.handle_event(account, jid, event.type_)
 
     @dbus.service.method(INTERFACE, in_signature='s', out_signature='a{sv}')
     def contact_info(self, jid):
@@ -780,10 +914,16 @@ class SignalObject(dbus.service.Object):
             accounts = gajim.connections.keys()
             for acct in accounts:
                 if gajim.account_is_connected(acct):
-                    account = acct
-                    break
+                    if not gajim.connections[acct].is_zeroconf:
+                        account = acct
+                        break
             if not account:
                 return
+
+        if gajim.connections[account].is_zeroconf:
+            # zeroconf not support groupchats
+            return
+
         if not nick:
             nick = ''
             gajim.interface.instances[account]['join_gc'] = \
